@@ -1,5 +1,4 @@
-import warnings
-from typing import Union, Coroutine, Any, Dict, List, Tuple, Generator
+from typing import Any, Coroutine, Dict, Generator, List, Tuple, Union
 
 from .account import Account, Thresholds
 from .asset import Asset
@@ -11,10 +10,10 @@ from .call_builder.data_call_builder import DataCallBuilder
 from .call_builder.effects_call_builder import EffectsCallBuilder
 from .call_builder.fee_stats_call_builder import FeeStatsCallBuilder
 from .call_builder.ledgers_call_builder import LedgersCallBuilder
+from .call_builder.liquidity_pools_builder import LiquidityPoolsBuilder
 from .call_builder.offers_call_builder import OffersCallBuilder
 from .call_builder.operations_call_builder import OperationsCallBuilder
 from .call_builder.orderbook_call_builder import OrderbookCallBuilder
-from .call_builder.paths_call_builder import PathsCallBuilder
 from .call_builder.payments_call_builder import PaymentsCallBuilder
 from .call_builder.root_call_builder import RootCallBuilder
 from .call_builder.strict_receive_paths_call_builder import (
@@ -27,20 +26,24 @@ from .call_builder.transactions_call_builder import TransactionsCallBuilder
 from .client.base_async_client import BaseAsyncClient
 from .client.base_sync_client import BaseSyncClient
 from .client.requests_client import RequestsClient
-from .exceptions import TypeError, NotFoundError, raise_request_exception
+from .client.response import Response
+from .exceptions import NotFoundError, TypeError, raise_request_exception
 from .fee_bump_transaction import FeeBumpTransaction
 from .fee_bump_transaction_envelope import FeeBumpTransactionEnvelope
 from .helpers import parse_transaction_envelope_from_xdr
 from .keypair import Keypair
 from .memo import NoneMemo
+from .muxed_account import MuxedAccount
+from .operation import (
+    AccountMerge,
+    PathPaymentStrictReceive,
+    PathPaymentStrictSend,
+    Payment,
+)
 from .sep.exceptions import AccountRequiresMemoError
 from .transaction import Transaction
 from .transaction_envelope import TransactionEnvelope
-from .utils import (
-    urljoin_with_query,
-    MUXED_ACCOUNT_STARTING_LETTER,
-)
-from .xdr import Xdr
+from .utils import MUXED_ACCOUNT_STARTING_LETTER, urljoin_with_query
 
 __all__ = ["Server"]
 
@@ -126,6 +129,7 @@ class Server:
             self.__check_memo_required_sync(tx)
         data = {"tx": xdr}
         resp = self._client.post(url=url, data=data)
+        assert isinstance(resp, Response)
         raise_request_exception(resp)
         return resp.json()
 
@@ -143,7 +147,8 @@ class Server:
         if not skip_memo_required_check:
             await self.__check_memo_required_async(tx)
         data = {"tx": xdr}
-        resp = await self._client.post(url=url, data=data)
+        resp = await self._client.post(url=url, data=data)  # type: ignore[misc]
+        assert isinstance(resp, Response)
         raise_request_exception(resp)
         return resp.json()
 
@@ -226,6 +231,13 @@ class Server:
         """
         return LedgersCallBuilder(horizon_url=self.horizon_url, client=self._client)
 
+    def liquidity_pools(self) -> LiquidityPoolsBuilder:
+        """
+        :return: New :class:`stellar_sdk.call_builder.LiquidityPoolsBuilder` object configured by
+            a current Horizon server configuration.
+        """
+        return LiquidityPoolsBuilder(horizon_url=self.horizon_url, client=self._client)
+
     def offers(self) -> OffersCallBuilder:
         """
         :return: New :class:`stellar_sdk.call_builder.OffersCallBuilder` object configured by
@@ -254,37 +266,6 @@ class Server:
             selling=selling,
         )
 
-    def paths(
-        self,
-        source_account: str,
-        destination_account: str,
-        destination_asset: Asset,
-        destination_amount: str,
-    ) -> PathsCallBuilder:
-        """
-        :param source_account: The sender's account ID. Any returned path must use a source that the sender can hold.
-        :param destination_account: The destination account ID that any returned path should use.
-        :param destination_asset: The destination asset.
-        :param destination_amount: The amount, denominated in the destination asset, that any returned path should be able to satisfy.
-        :return: New :class:`stellar_sdk.call_builder.PathsCallBuilder` object configured by
-            a current Horizon server configuration.
-        """
-
-        warnings.warn(
-            "Will be removed in version v3.0.0, "
-            "use stellar_sdk.server.strict_receive_paths",
-            DeprecationWarning,
-        )
-
-        return PathsCallBuilder(
-            horizon_url=self.horizon_url,
-            client=self._client,
-            source_account=source_account,
-            destination_account=destination_account,
-            destination_asset=destination_asset,
-            destination_amount=destination_amount,
-        )
-
     def strict_receive_paths(
         self,
         source: Union[str, List[Asset]],
@@ -385,11 +366,14 @@ class Server:
         )
 
     def load_account(
-        self, account_id: Union[Keypair, str]
+        self, account_id: Union[MuxedAccount, Keypair, str]
     ) -> Union[Account, Coroutine[Any, Any, Account]]:
-        """Fetches an account's most current state in the ledger and then creates
+        """Fetches an account's most current base state (like sequence) in the ledger and then creates
         and returns an :class:`stellar_sdk.account.Account` object.
 
+        If you want to get complete account information, please
+        use :func:`stellar_sdk.server.Server.accounts`.
+
         :param account_id: The account to load.
         :return: an :class:`stellar_sdk.account.Account` object.
         :raises:
@@ -399,17 +383,19 @@ class Server:
             :exc:`BadResponseError <stellar_sdk.exceptions.BadResponseError>`
             :exc:`UnknownRequestError <stellar_sdk.exceptions.UnknownRequestError>`
         """
-
-        if isinstance(account_id, Keypair):
-            account = account_id.public_key
+        if isinstance(account_id, str):
+            account = MuxedAccount.from_account(account_id)
+        elif isinstance(account_id, Keypair):
+            account = MuxedAccount.from_account(account_id.public_key)
         else:
             account = account_id
         if self.__async:
             return self.__load_account_async(account)
         return self.__load_account_sync(account)
 
-    async def __load_account_async(self, account_id: str) -> Account:
-        resp = await self.accounts().account_id(account_id=account_id).call()
+    async def __load_account_async(self, account_id: MuxedAccount) -> Account:
+        resp = await self.accounts().account_id(account_id=account_id.account_id).call()  # type: ignore[misc]
+        assert isinstance(resp, dict)
         sequence = int(resp["sequence"])
         thresholds = Thresholds(
             resp["thresholds"]["low_threshold"],
@@ -421,8 +407,9 @@ class Server:
         account.thresholds = thresholds
         return account
 
-    def __load_account_sync(self, account_id: str) -> Account:
-        resp = self.accounts().account_id(account_id=account_id).call()
+    def __load_account_sync(self, account_id: MuxedAccount) -> Account:
+        resp = self.accounts().account_id(account_id=account_id.account_id).call()  # type: ignore[misc]
+        assert isinstance(resp, dict)
         sequence = int(resp["sequence"])
         thresholds = Thresholds(
             resp["thresholds"]["low_threshold"],
@@ -434,7 +421,9 @@ class Server:
         account.thresholds = thresholds
         return account
 
-    def __check_memo_required_sync(self, transaction: Transaction) -> None:
+    def __check_memo_required_sync(
+        self, transaction: Union[Transaction, FeeBumpTransaction]
+    ) -> None:
         if isinstance(transaction, FeeBumpTransaction):
             transaction = transaction.inner_transaction_envelope.transaction
         if not (transaction.memo is None or isinstance(transaction.memo, NoneMemo)):
@@ -448,6 +437,7 @@ class Server:
                 account_resp = self.accounts().account_id(destination).call()
             except NotFoundError:
                 continue
+            assert isinstance(account_resp, dict)
             self.__check_destination_memo(account_resp, index, destination)
 
     async def __check_memo_required_async(
@@ -463,7 +453,7 @@ class Server:
             if destination.startswith(MUXED_ACCOUNT_STARTING_LETTER):
                 continue
             try:
-                account_resp = await self.accounts().account_id(destination).call()
+                account_resp = await self.accounts().account_id(destination).call()  # type: ignore[misc]
             except NotFoundError:
                 continue
             self.__check_destination_memo(account_resp, index, destination)
@@ -485,15 +475,17 @@ class Server:
         self, transaction: Transaction
     ) -> Generator[Tuple[int, str], Any, Any]:
         destinations = set()
-        memo_required_operation_code = (
-            Xdr.const.PAYMENT,
-            Xdr.const.ACCOUNT_MERGE,
-            Xdr.const.PATH_PAYMENT_STRICT_RECEIVE,
-            Xdr.const.PATH_PAYMENT_STRICT_SEND,
-        )
         for index, operation in enumerate(transaction.operations):
-            if operation.type_code() in memo_required_operation_code:
-                destination: str = operation.destination
+            if isinstance(
+                operation,
+                (
+                    Payment,
+                    AccountMerge,
+                    PathPaymentStrictSend,
+                    PathPaymentStrictReceive,
+                ),
+            ):
+                destination: str = operation.destination.account_id
             else:
                 continue
             if destination in destinations:
@@ -519,11 +511,12 @@ class Server:
 
     def __fetch_base_fee_sync(self) -> int:
         latest_ledger = self.ledgers().order(desc=True).limit(1).call()
+        assert isinstance(latest_ledger, dict)
         base_fee = self.__handle_base_fee(latest_ledger)
         return base_fee
 
     async def __fetch_base_fee_async(self) -> int:
-        latest_ledger = await self.ledgers().order(desc=True).limit(1).call()
+        latest_ledger = await self.ledgers().order(desc=True).limit(1).call()  # type: ignore[misc]
         base_fee = self.__handle_base_fee(latest_ledger)
         return base_fee
 
@@ -539,7 +532,7 @@ class Server:
             )
         return base_fee
 
-    def close(self) -> Union[None, Coroutine[Any, Any, None]]:
+    def close(self) -> Union[None, Coroutine[Any, Any, None]]:  # type: ignore[misc]
         """Close underlying connector.
 
         Release all acquired resources.
@@ -547,7 +540,7 @@ class Server:
         if self.__async:
             return self.__close_async()
         else:
-            return self.__close_sync()
+            return self.__close_sync()  # type: ignore[func-returns-value]
 
     async def __close_async(self) -> None:
         await self._client.close()
@@ -559,10 +552,13 @@ class Server:
         return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb) -> None:
-        await self.close()
+        await self.close()  # type: ignore[misc]
 
     def __enter__(self) -> "Server":
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
+
+    def __str__(self):
+        return f"<Server [horizon_url={self.horizon_url}, client={self._client}]>"
